==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/IdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.IdentityArgs.builder
import com.pulumi.azurenative.search.kotlin.enums.IdentityType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Identity for the resource.
 * @property type The identity type.
 */
public data class IdentityArgs(
    public val type: Output<IdentityType>,
) : ConvertibleToJava<com.pulumi.azurenative.search.inputs.IdentityArgs> {
    override fun toJava(): com.pulumi.azurenative.search.inputs.IdentityArgs =
        com.pulumi.azurenative.search.inputs.IdentityArgs.builder()
            .type(type.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IdentityArgs].
 */
@PulumiTagMarker
public class IdentityArgsBuilder internal constructor() {
    private var type: Output<IdentityType>? = null

    /**
     * @param value The identity type.
     */
    @JvmName("bxcecrogtxucfcgb")
    public suspend fun type(`value`: Output<IdentityType>) {
        this.type = value
    }

    /**
     * @param value The identity type.
     */
    @JvmName("sqlbuwqoofnstwte")
    public suspend fun type(`value`: IdentityType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): IdentityArgs = IdentityArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/search/kotlin/inputs/IdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.search.kotlin.inputs

import com.pulumi.azurenative.search.inputs.IdentityArgs.builder
import com.pulumi.azurenative.search.kotlin.enums.IdentityType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Identity for the resource.
 * @property type The identity type.
 */
public data class IdentityArgs(
    public val type: Output<IdentityType>,
) : ConvertibleToJava<com.pulumi.azurenative.search.inputs.IdentityArgs> {
    override fun toJava(): com.pulumi.azurenative.search.inputs.IdentityArgs =
        com.pulumi.azurenative.search.inputs.IdentityArgs.builder()
            .type(type.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [IdentityArgs].
 */
@PulumiTagMarker
public class IdentityArgsBuilder internal constructor() {
    private var type: Output<IdentityType>? = null

    /**
     * @param value The identity type.
     */
    @JvmName("lovrqdjrodicpbxo")
    public suspend fun type(`value`: Output<IdentityType>) {
        this.type = value
    }

    /**
     * @param value The identity type.
     */
    @JvmName("nqjjcrpgivfgsiss")
    public suspend fun type(`value`: IdentityType) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): IdentityArgs = IdentityArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
